summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/macros/kexipart/keximacrotextview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/macros/kexipart/keximacrotextview.h')
-rw-r--r--kexi/plugins/macros/kexipart/keximacrotextview.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kexi/plugins/macros/kexipart/keximacrotextview.h b/kexi/plugins/macros/kexipart/keximacrotextview.h
index 5101c30b..0acfa9ef 100644
--- a/kexi/plugins/macros/kexipart/keximacrotextview.h
+++ b/kexi/plugins/macros/kexipart/keximacrotextview.h
@@ -40,10 +40,10 @@ class KexiMacroTextView : public KexiMacroView
*
* \param mainwin The \a KexiMainWindow instance this \a KexiViewBase
* belongs to.
* \param tqparent The tqparent widget this widget should be displayed in.
* \param macro The \a KoMacro::Macro instance this view is for.
*/
- KexiMacroTextView(KexiMainWindow *mainwin, TQWidget *tqparent, ::KoMacro::Macro* const macro);
+ KexiMacroTextView(KexiMainWindow *mainwin, TQWidget *parent, ::KoMacro::Macro* const macro);
/**
* Destructor.
@@ -40,10 +40,10 @@ class KexiMacroTextView : public KexiMacroView
* \param mainwin The \a KexiMainWindow instance this \a KexiViewBase
* belongs to.
- * \param tqparent The tqparent widget this widget should be displayed in.
+ * \param parent The parent widget this widget should be displayed in.
* \param macro The \a KoMacro::Macro instance this view is for.
*/